@@ -18,31 +18,12 @@ func init() {
 	logf.SetLogger(logf.ZapLogger(true))
 }
 
-func TestChecksumIsURLNo(t *testing.T) {
-	isURL, err := checksumIsURL("checksum-goes-here")
-	if isURL {
-		t.Fail()
-	}
-	if err != nil {
-		t.Fail()
-	}
-}
-
-func TestChecksumIsURLYes(t *testing.T) {
-	isURL, err := checksumIsURL("http://checksum-goes-here")
-	if !isURL {
-		t.Fail()
-	}
-	if err != nil {
-		t.Fail()
-	}
-}
-
 func TestGetUpdateOptsForNodeVirtual(t *testing.T) {
 	host := &metal3v1alpha1.BareMetalHost{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "myhost",
 			Namespace: "myns",
+			UID:       "27720611-e5d1-45d3-ba3a-222dcfaa4ca2",
 		},
 		Spec: metal3v1alpha1.BareMetalHostSpec{
 			Image: &metal3v1alpha1.Image{
@@ -87,7 +68,7 @@ func TestGetUpdateOptsForNodeVirtual(t *testing.T) {
 		},
 		{
 			Path:  "/instance_uuid",
-			Value: "provisioning-id",
+			Value: "27720611-e5d1-45d3-ba3a-222dcfaa4ca2",
 		},
 		{
 			Path:  "/instance_info/root_gb",
@@ -128,6 +109,7 @@ func TestGetUpdateOptsForNodeDell(t *testing.T) {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "myhost",
 			Namespace: "myns",
+			UID:       "27720611-e5d1-45d3-ba3a-222dcfaa4ca2",
 		},
 		Spec: metal3v1alpha1.BareMetalHostSpec{
 			Image: &metal3v1alpha1.Image{
@@ -172,7 +154,7 @@ func TestGetUpdateOptsForNodeDell(t *testing.T) {
 		},
 		{
 			Path:  "/instance_uuid",
-			Value: "provisioning-id",
+			Value: "27720611-e5d1-45d3-ba3a-222dcfaa4ca2",
 		},
 		{
 			Path:  "/instance_info/root_gb",
